@@ -39,9 +39,14 @@ betalinkr <- function(webarray, index = "bray", binary=TRUE, partitioning="commo
   #-> not using this as it actually made the function slower! (in one test case)
   
   # species community matrix (combining upper and lower of bipartite web)
+    # now ensuring a single entry per species also in named foodwebs (adding ingoing and outgoing links, instead of counting them separately)
   specmx.lower <- apply(webarray, c(3,1), sum)
   specmx.higher <- apply(webarray, c(3,2), sum)
-  specmx.all <- cbind(specmx.lower, specmx.higher)  # e.g. sites X (plants, pollinators)
+  specmx.higher.unique <- specmx.higher[, !(colnames(specmx.higher) %in% colnames(specmx.lower))]
+  if (is.null(colnames(specmx.higher))) {specmx.higher.unique <- specmx.higher}  # if no species names are given, assuming bipartite webs
+  specmx.all <- cbind(specmx.lower, specmx.higher.unique)  # e.g. sites X (plants, pollinators); 
+  duplicolnames <- setdiff(colnames(specmx.higher), colnames(specmx.higher.unique))
+  specmx.all[, duplicolnames] <- specmx.all[, duplicolnames] + specmx.higher[, duplicolnames]
 
   if (partitioning=="poisot"){
     if (partition.st | partition.rr){warning("further partitioning only available with method partitioning='commondenom'")}
